@@ -467,7 +467,7 @@ gpd_canceled (GnomeDruid *druid, gpointer user_data)
 static void 
 gpd_help (GnomeDruid *druid, gpointer user_data)
 {
-	gnome_help_display_desktop (NULL, "gnome-pilot", "gnome-pilot.xml", "conftool-pilots", NULL);
+	gnome_help_display_desktop (NULL, "gnome-pilot", "gnome-pilot.xml", "assistant", NULL);
 }
 
 static void
