@@ -800,13 +800,13 @@ static const char *vendor_product_ids[] =
 	"Vendor=0830 ProdID=0031", /* Palm Tungsten Z */
 	"Vendor=0830 ProdID=0070", /* Palm Zire */
 	"Vendor=0830 ProdID=0080", /* Palm M100 */
-	"Vendor=054C ProdID=0038", /* Sony Clie 3.5 */
-	"Vendor=054C ProdID=0066", /* Sony Clie 4.0 */
-	"Vendor=054C ProdID=0095", /* Sony Clie S360 */
-	"Vendor=054C ProdID=009A", /* Sony Clie 4.1 */
-	"Vendor=054C ProdID=00DA", /* Sony Clie NX60 */
-	"Vendor=054C ProdID=00E9", /* Sony Clie NZ90V */
-	"Vendor=04E8 ProdID=8001", /* Samsung SCH-I330 */
+	"Vendor=054c ProdID=0038", /* Sony Clie 3.5 */
+	"Vendor=054c ProdID=0066", /* Sony Clie 4.0 */
+	"Vendor=054c ProdID=0095", /* Sony Clie S360 */
+	"Vendor=054c ProdID=009a", /* Sony Clie 4.1 */
+	"Vendor=054c ProdID=00da", /* Sony Clie NX60 */
+	"Vendor=054c ProdID=00c9", /* Sony Clie NZ90V */
+	"Vendor=04e8 ProdID=8001", /* Samsung SCH-I330 */
 	NULL
 };
 
@@ -862,7 +862,7 @@ visor_devices_in (GIOChannel *io_channel,
 			continue;
 		
 		for (i = 0; vendor_product_ids[i] != NULL; i++) {
-			if (!strncmp (line + strlen ("P:  "), 
+			if (!g_strncasecmp (line + strlen ("P:  "), 
 				      vendor_product_ids[i], 
 				      strlen (vendor_product_ids[i]))) {
 				visor_exists = TRUE;
